#define XERR "memorybridge"
#include "memorybridge.ih"

    // by X

MemoryBridge::MemoryBridge(MemoryBridge &&tmp)
{
    memcpy(static_cast<void *>(this), &tmp, sizeof(MemoryBridge));

    tmp.d_accessPtr = 0;
    tmp.d_access = &MemoryBridge::unavailable;
}
