#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by drop.cc

void MemoryAccess::killBlocks()
{
    for (size_t idx = 0; idx != d_nBlocks; ++idx)
        killID(d_block[idx]);                   // remove data block idx
}

//        if (d_block[idx] != -1)
//            xerr("kill data block " << idx << ": " << d_block[idx]);

