    The tt(bufSize) parameter required by the second bf(MemoryStream)
constructor and the tt(open) member (see below) specifies the default number
nummber of shared memory memory blocks and their sizes. The size of the memory
blocks is specified as tt(k, M) or tt(G), indicating block sizes in kilo-,
Mega- and GigaBytes. Before those letters the default number of blocks is
specified. E.g., tt("100M"). Internally the number of kiloBytes is converted
to `pages', using the system's page size, which is commonly equal to 4 kB (so
when specifying tt("5k") then the stream prepares for two shared data
segments, each having a capacity of 4 kB. The number of MegaBytes is used as
specified, and when specifying tt(GB) the data segments are .5 GB.

    The number of shared data segments is aotomatically enlarged when the
current capacity is exceeded, and the potentially available data segments are
initially not allocated: they're allocated once information is written into
their areas.
