#include "multibuf.ih"

void MultiBuf::insert(std::ostream &os, Mode mode)
{
    if (mode == ALL)
        return;

    Stream *stream = find(os);
    if (stream != 0)
        stream->d_mode = mode;
    else
        d_os.push_back( Stream{ os, mode } );
}
