#define XERR "flock"
#include "flock.ih"

    // by 

void Flock::exclusive() const
{
    if (flock(d_fd, LOCK_EX) == -1)
        throw Exception{} << "can't get an exclusive lock for fd " << 
                            d_fd << ": " << errnodescr;
}
