#define XERR "memoryaccess"
#include "memoryaccess.ih"

// make the data block containing byte offset available 

    // by io.cc, memorybridge/load.f

bool MemoryAccess::load(size_t offset)
{
    size_t block = bufLimits(offset);

    if (block == d_nBlocks)
        return false;

    get(block);                                 // make the block available

//xerr("  block: " << block << 
//    ", begin: " << d_blockBegin << ", offset: " << offset << 
//    ", end: " << d_blockEnd << "\n"
//    ", data: " << (void *)d_data << ": " << (void *)beginPtr() << " to " << 
//    (void *)endPtr() );


    return true;
}

