#include "arg.ih"

// static
Arg &Arg::init(int accept, char const *optstring,
                 LongOption const *const begin,
                 LongOption const *const end,
                 int argc, char **argv)
{
    static Arg arg{ accept, optstring, begin, end, argc, argv };
    s_arg = &arg;
    return arg;
}
