#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by create.cc

//static
size_t MemoryAccess::memoryAccessSize(size_t nBlocks)
{
    return  s_pageSize *
            divPlus(
                sizeof(MemoryAccess) + (nBlocks - 1) * sizeof(int),
                s_pageSize); 
    
}
