#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by get.cc refresh.cc loadid.cc create.cc setdataptr.cc

// static
void *MemoryAccess::connect(int id)
{
    void *ret = shmat(id, 0, 0);                // the MemoryAccess's size 
                                                // is set by getID
    if (ret == reinterpret_cast<void *>(-1))
        ret = 0;

//    xerr("connected segment " << id << ": " << (ret != 0));

    return ret;   
}







