#define XERR "memoryaccess"
#include "memoryaccess.ih"

// disconnect(id) (1.) disconnects block[idx] if it's != 0, detaching d_data
// disconnect(ptr) (2.) disconnects the MemoryAccess object at 'ptr' itself

    // by drop.cc

//static
void MemoryAccess::disconnect(MemoryAccess const *ptr)
{
    if (shmdt(ptr) != 0)
       emsg << XERR ": Could not disconnect the MemoryAccess object" << endl;
}
