#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by load.cc

void MemoryAccess::get(size_t blockIdx)
{
//xerr("connect block " << blockIdx);

    int id = d_block[blockIdx];             // obtain blockIdx's ID:

    if (id == -1)                           // not yet used before, so
        id = getID(d_blockSize, d_accessMode);  // get its ID

    activate(blockIdx, id);                 // updates d_data
}
