#define XERR "memorystream"
#include "memorystream.ih"

MemoryStream::MemoryStream(
                string const &bufSize, bool erase,
                std::ios::openmode openMode, size_t access)
:
    MemoryBuf(bufSize, erase, openMode, access),                    // 3
    std::iostream(this)
{}
