#define XERR "memorybuf/"  __FILE__

#include "memorybuf.ih"

// overrides
int MemoryBuf::pbackfail(int chInt)
{
        // reset to the previous position (maybe reloading the segment)
        // or writing ch fails -> EOF else 0
    if (d_bridge.offset() == 0)
        return EOF;

    seekoff(-1, ios::cur);

    char ch = chInt;
    return d_bridge.write(static_cast<char *>(&ch), 1) == 0 ? EOF : 0;
}

//xerr("");

