#include <iostream>
c
#include <bobcat/flock>

using namespace std;
using namespace FBB;


int main(int argc, char **argv)
try
{
    if (argc < 3)
    {
        cerr << "need lockfile name and e or .\n";
        return 1;
    }

    Flock flock{ argv[1] };
    cout << "FD = " << flock.fd() << '\n';


    if (string str; *argv[2] == 'e')
    {
        flock.exclusive();
        cout << "press Enter... ";
        getline(cin, str);
    }
    else
    {
        bool ok = flock.exclusive(3s);
        cout << "obtained a lock: " << ok << '\n';
        if (ok)
        {
            cout << "press Enter... ";
            getline(cin, str);
        }
    }
}
catch (...)
{
    cerr << "caught an exception\n";
}
