#define XERR "memoryaccess"
#include "memoryaccess.ih"

// since MemoryAccess is installed by create() and refresh() using
// placement new it's not destroyed. That's intended. See the emsg below

MemoryAccess::~MemoryAccess()
{
    emsg << "The MemoryAccess destructor does not disconnect a shared segment\n"
            "       To disconnect it call 'killBlocks()" << endl;
}
