#define XERR "memoryaccess"
#include "memoryaccess.ih"

// completely remove the shared segment having ID 'id'

    // by drop.cc extend.cc removeidx (.f)

// static
void MemoryAccess::killID(int id)
{
    if (id == -1)                       // no such block
        return;

    struct shmid_ds buf;

    if (shmctl(id, IPC_RMID, &buf) != 0)
        throw Exception{} << "Could not remove shared segment " << id;
}
