#define XERR "memoryaccess"
#include "memoryaccess.ih"

    // by activate.cc

void MemoryAccess::setDataPtr(int id)
{
    if (d_data = static_cast<char *>(connect(id)); d_data == 0)
        throw Exception{} << XERR ": can't connect shared data block " 
                              "(id " << id << ')';
}
